==> ruby-merb-cache-1.0.15.tgz: lib/ruby/gems/1.8/gems/merb-cache-1.0.15/spec/merb-cache/stores/strategy/gzip_store_spec.rb <==
require File.dirname(__FILE__) + '/../../../spec_helper'
require File.dirname(__FILE__) + '/abstract_strategy_store_spec'

describe Merb::Cache::GzipStore do
  it_should_behave_like 'all strategy stores'

  before(:each) do
    @klass = Merb::Cache::GzipStore
    @store = Merb::Cache::GzipStore[DummyStore].new
  end

  describe "#writable?" do
    it "should always be true" do
      @store.writable?(:foo).should be_true
      @store.writable?('foo').should be_true
      @store.writable?(123).should be_true
    end
  end

  describe "#read" do
    it "should return nil if hash does not exist as a key in any context store" do
      @store.stores.each {|s| s.should_receive(:read).with(:foo, :bar => :baz).and_return nil}

      @store.read(:foo, :bar => :baz).should be_nil
    end

    it "should return the data from the context store when there is a hash key match" do
      @store.stores.first.should_receive(:read).with(:foo, {}).and_return @store.compress("bar")

      @store.read(:foo).should == "bar"
    end
  end

  describe "#write" do
    it "should pass the hashed key to the context store" do
      @store.stores.first.should_receive(:write).with(:foo,  @store.compress('body'), {}, {}).and_return true

      @store.write(:foo, 'body').should be_true
    end

    it "should use the parameters to create the hashed key" do
      @store.stores.first.should_receive(:write).with(:foo, @store.compress('body'), {:bar => :baz}, {}).and_return true

      @store.write(:foo, 'body', :bar => :baz).should be_true
    end
  end

  describe "#fetch" do
    # not sure how to spec this yet
  end
end

==> ruby-merb-cache-1.1.3p0.tgz: lib/ruby/gems/1.8/gems/merb-cache-1.1.3/spec/merb-cache/stores/strategy/gzip_store_spec.rb <==
require 'spec_helper'
require 'merb-cache/stores/strategy/abstract_strategy_store_spec'

describe Merb::Cache::GzipStore do
  it_should_behave_like 'all strategy stores'

  before(:each) do
    @klass = Merb::Cache::GzipStore
    @store = Merb::Cache::GzipStore[DummyStore].new
  end

  describe "#writable?" do
    it "should be true whatever the key" do
      @store.writable?(:foo).should be_true
      @store.writable?('foo').should be_true
      @store.writable?(123).should be_true
    end

    it "should be false if none of the context caches are writable" do
      @store.stores.each {|s| s.should_receive(:writable?).and_return false}

      @store.writable?(:foo).should be_false
    end
  end

  describe "#read" do
    it "should return nil if hash does not exist as a key in any context store" do
      @store.stores.each {|s| s.should_receive(:read).with(:foo, :bar => :baz).and_return nil}

      @store.read(:foo, :bar => :baz).should be_nil
    end

    it "should return the data from the context store when there is a hash key match" do
      @store.stores.first.should_receive(:read).with(:foo, {}).and_return @store.compress("bar")

      @store.read(:foo).should == "bar"
    end
  end

  describe "#write" do
    it "should pass the hashed key to the context store" do
      @store.stores.first.should_receive(:write).with(:foo,  @store.compress('body'), {}, {}).and_return true

      @store.write(:foo, 'body').should be_true
    end

    it "should use the parameters to create the hashed key" do
      @store.stores.first.should_receive(:write).with(:foo, @store.compress('body'), {:bar => :baz}, {}).and_return true

      @store.write(:foo, 'body', :bar => :baz).should be_true
    end
  end

  describe "#fetch" do
    # not sure how to spec this yet
  end
end
